"""
Freeway is a module for managing file system structures with recursive pattern rules.

.. moduleauthor:: Leandro Inocencio <cesio.arg@gmail.com>

"""

from .freeway import Freeway

__version__ = '0.0.4'
